'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index$1 = require('./index-0e20a87a.js');
const defaultIconPack = require('./default-icon-pack-d94ddba8.js');
const index$2 = require('./index-211dabb8.js');
const index = require('./index-c2763bbb.js');

/**
 * Days in 1 week.
 *
 * @name daysInWeek
 * @constant
 * @type {number}
 * @default
 */
/**
 * Milliseconds in 1 minute
 *
 * @name millisecondsInMinute
 * @constant
 * @type {number}
 * @default
 */

var millisecondsInMinute = 60000;

/**
 * @name differenceInMinutes
 * @category Minute Helpers
 * @summary Get the number of minutes between the given dates.
 *
 * @description
 * Get the signed number of full (rounded towards 0) minutes between the given dates.
 *
 * ### v2.0.0 breaking changes:
 *
 * - [Changes that are common for the whole library](https://github.com/date-fns/date-fns/blob/master/docs/upgradeGuide.md#Common-Changes).
 *
 * @param {Date|Number} dateLeft - the later date
 * @param {Date|Number} dateRight - the earlier date
 * @param {Object} [options] - an object with options.
 * @param {String} [options.roundingMethod='trunc'] - a rounding method (`ceil`, `floor`, `round` or `trunc`)
 * @returns {Number} the number of minutes
 * @throws {TypeError} 2 arguments required
 *
 * @example
 * // How many minutes are between 2 July 2014 12:07:59 and 2 July 2014 12:20:00?
 * const result = differenceInMinutes(
 *   new Date(2014, 6, 2, 12, 20, 0),
 *   new Date(2014, 6, 2, 12, 7, 59)
 * )
 * //=> 12
 *
 * @example
 * // How many minutes are between 10:01:59 and 10:00:00
 * const result = differenceInMinutes(
 *   new Date(2000, 0, 1, 10, 0, 0),
 *   new Date(2000, 0, 1, 10, 1, 59)
 * )
 * //=> -1
 */

function differenceInMinutes(dateLeft, dateRight, options) {
  index.requiredArgs(2, arguments);
  var diff = index.differenceInMilliseconds(dateLeft, dateRight) / millisecondsInMinute;
  return index.getRoundingMethod(options === null || options === void 0 ? void 0 : options.roundingMethod)(diff);
}

/**
 * Scroll to bottom of an element.
 *
 * Works in all browsers - just that in Safari, the smooth scrolling doesn't work.
 * @param el The bottom of which element you want to scroll down to
 */
const smoothScrollToBottom = (el) => {
  if (el == null)
    return;
  el.scrollTo({ top: el.scrollHeight, behavior: 'smooth' });
};

const dyteChatCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{display:flex;height:100%;width:100%;flex-direction:column;font-family:var(--dyte-font-family, sans-serif);font-size:14px}h3{margin:var(--dyte-space-0, 0px);display:flex;height:var(--dyte-space-12, 48px);align-items:center;justify-content:center;font-size:16px;font-weight:400;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));text-align:center}.chat-container{box-sizing:border-box;display:flex;flex-direction:column;padding-top:var(--dyte-space-4, 16px);padding-bottom:var(--dyte-space-4, 16px);flex:1 0 0px;overflow-y:scroll}.chat-container .spacer{flex:1 1 auto}.chat-container .chat{flex:0 0 auto}.chat-input{box-sizing:border-box;display:flex;flex-direction:column;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));border-top:var(--dyte-border-width-sm, 1px) solid rgb(var(--dyte-colors-background-600, 60 60 60))}textarea{box-sizing:border-box;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));padding:var(--dyte-space-3, 12px);color:rgb(var(--dyte-colors-text-1000, 255 255 255))}textarea::-moz-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea:-ms-input-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea::placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}textarea{outline:2px solid transparent;outline-offset:2px;resize:none;overflow:hidden;border-width:var(--dyte-border-width-none, 0);border-style:none;font-family:var(--dyte-font-family, sans-serif);min-height:80px;font-size:14px}dyte-button.active{background-color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64));--tw-text-opacity:1;color:rgba(var(--dyte-colors-background-1000, 8 8 8) / var(--tw-text-opacity))}.chat-buttons{display:flex;align-items:center;justify-content:space-between;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px)}.chat-buttons .left dyte-button{margin-right:var(--dyte-space-1, 4px)}.chat-buttons .left dyte-button dyte-icon{height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px)}.chat-buttons .left dyte-button:hover,.chat-buttons .left dyte-button:focus{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.chat-buttons .right dyte-button:hover,.chat-buttons .right dyte-button:focus{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-opacity:1;--tw-ring-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-ring-opacity));--tw-ring-offset-width:2px;--tw-ring-offset-color:rgb(var(--dyte-colors-background-800, 30 30 30))}.chat-buttons>div{display:flex;align-items:center}.file-picker{display:none}.chat *:first-child{margin-top:var(--dyte-space-0, 0px)}.chat .head{display:flex;align-items:center}.chat .head .name{margin-right:var(--dyte-space-4, 16px);font-size:12px;font-weight:700}.chat .head .time{font-size:12px;color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}.chat .body{margin-top:var(--dyte-space-2, 8px);margin-bottom:var(--dyte-space-2, 8px);font-size:14px;line-height:1.25rem}.chat .body .emoji{font-size:20px}dyte-text-message,dyte-image-message,dyte-file-message{margin-top:var(--dyte-space-4, 16px);display:block;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);font-family:var(--dyte-font-family, sans-serif);color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));box-sizing:border-box}*[is-continued]{margin-top:var(--dyte-space-3, 12px)}dyte-text-message[is-continued]{margin-top:var(--dyte-space-2, 8px)}.chat .image{position:relative;height:var(--dyte-space-40, 160px);max-width:var(--dyte-space-64, 256px);cursor:pointer}.chat .image img{display:none;height:100%;width:100%;border-radius:var(--dyte-border-radius-sm, 4px);-o-object-fit:cover;object-fit:cover}.chat .image .image-spinner{display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center;border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity))}.chat .image .image-spinner dyte-spinner{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-text-opacity))}.chat .image .image-errored{display:flex;height:100%;width:100%;flex-direction:column;align-items:center;justify-content:center;border-radius:var(--dyte-border-radius-sm, 4px);background-color:rgba(var(--dyte-colors-danger, 255 45 45) / 0.1);--tw-text-opacity:1;color:rgba(var(--dyte-colors-danger, 255 45 45) / var(--tw-text-opacity))}.chat .image .actions{display:none;height:var(--dyte-space-8, 32px);align-items:center;position:absolute;top:var(--dyte-space-2, 8px);right:var(--dyte-space-2, 8px);border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-900, 26 26 26) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));overflow:hidden;--tw-shadow:0 10px 15px -3px rgb(0 0 0 / 0.1), 0 4px 6px -4px rgb(0 0 0 / 0.1);--tw-shadow-colored:0 10px 15px -3px var(--tw-shadow-color), 0 4px 6px -4px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.chat .image .actions .action{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);border-radius:var(--dyte-border-radius-none, 0);border-width:var(--dyte-border-width-none, 0);border-style:none;background-color:transparent;--tw-shadow:0 0 #0000;--tw-shadow-colored:0 0 #0000;box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow)}.chat .image .actions .action:hover{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}.image.loaded img{display:block}.image.loaded .image-spinner{display:none}.image:hover .actions,.image:focus .actions{display:flex}.chat .file{display:flex;align-items:center;padding-left:var(--dyte-space-2, 8px);padding-right:var(--dyte-space-2, 8px);padding-top:var(--dyte-space-1\\.5, 6px);padding-bottom:var(--dyte-space-1\\.5, 6px);border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}.chat .file .file-data{flex:1 1 0%}.chat .file .file-data .name{color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.chat .file .file-data .file-data-split{margin-top:var(--dyte-space-0\\.5, 2px);display:flex;align-items:center;font-size:12px}.chat .file .file-data .file-data-split .ext{margin-right:var(--dyte-space-2, 8px);text-transform:uppercase}.chat .file .file-data .file-data-split .divider{height:var(--dyte-space-4, 16px);width:var(--dyte-space-0\\.5, 2px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}.chat .file .file-data .file-data-split .size{margin-left:var(--dyte-space-2, 8px)}.chat .file dyte-button{border-radius:var(--dyte-border-radius-sm, 4px);border-width:var(--dyte-border-width-none, 0);border-style:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255))}.chat .file dyte-button:hover{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}a{--tw-text-opacity:1;color:rgba(var(--dyte-colors-brand-300, 73 124 253) / var(--tw-text-opacity));-webkit-text-decoration-line:none;text-decoration-line:none}a:hover{-webkit-text-decoration-line:underline;text-decoration-line:underline}#dropzone{position:absolute;top:var(--dyte-space-0, 0px);right:var(--dyte-space-0, 0px);bottom:var(--dyte-space-0, 0px);left:var(--dyte-space-0, 0px);z-index:10;display:none;flex-direction:column;align-items:center;justify-content:center;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-800, 30 30 30) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}#dropzone.active{display:flex;-webkit-animation:0.3s slide-up ease;animation:0.3s slide-up ease}@-webkit-keyframes slide-up{from{transform:translateY(100%)}to{transform:translateY(0%)}}@keyframes slide-up{from{transform:translateY(100%)}to{transform:translateY(0%)}}";

const DyteChat = class {
  constructor(hostRef) {
    index$1.registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$2.useLanguage();
    this.chat = [];
    this.shiftDown = false;
    this.now = new Date();
    this.autoScrollEnabled = true;
    this.dropzoneActivated = false;
    this.canSend = false;
    this.canSendTextMessage = false;
    this.canSendFiles = false;
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.host.addEventListener('dragover', (e) => {
      e.preventDefault();
      this.dropzoneActivated = true;
    });
    this.host.addEventListener('dragleave', () => {
      this.dropzoneActivated = false;
    });
    this.host.addEventListener('drop', (e) => {
      e.preventDefault();
      this.dropzoneActivated = false;
      this.handleFilesDataTransfer(e.dataTransfer.items);
    });
  }
  componentDidLoad() {
    this.textArea.focus();
  }
  componentDidRender() {
    if (this.autoScrollEnabled) {
      smoothScrollToBottom(this.chatEl);
    }
  }
  disconnectedCallback() {
    var _a;
    this.timeout && clearTimeout(this.timeout);
    typeof this.request === 'number' && cancelAnimationFrame(this.request);
    this.chatUpdateListener &&
      ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.removeListener('chatUpdate', this.chatUpdateListener));
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canSend = meeting.self.permissions.chatPublic.canSend;
      this.canSendTextMessage = meeting.self.permissions.chatPublic.text;
      this.canSendFiles = meeting.self.permissions.chatPublic.files;
      this.chat = meeting.chat.messages.map((message) => ({ type: 'chat', message }));
      this.chatUpdateListener = ({ message }) => {
        if (message != null) {
          this.chat = [...this.chat, { type: 'chat', message }];
        }
      };
      // update current time every minute
      const updateNow = () => {
        this.now = new Date();
        this.timeout = setTimeout(() => {
          if (this.request != null) {
            this.request = requestAnimationFrame(updateNow);
          }
        }, 60 * 1000);
      };
      this.request = requestAnimationFrame(updateNow);
      meeting.chat.addListener('chatUpdate', this.chatUpdateListener);
    }
  }
  handleSendMessage() {
    var _a;
    if (!this.canSend || !this.canSendTextMessage) {
      return;
    }
    const message = this.textArea.value.trim();
    if (message.length > 0) {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.sendTextMessage(message);
      this.textArea.value = '';
      this.textArea.style.height = 'auto';
    }
  }
  handleKeyDown(e) {
    // slack like typing experience
    if (e.key === 'Shift') {
      this.shiftDown = true;
    }
    else if (e.key === 'Enter' && this.shiftDown) {
      const height = this.textArea.clientHeight;
      if (height < 240) {
        this.textArea.style.height = this.textArea.clientHeight + 20 + 'px';
      }
    }
    else if (e.key === 'Enter') {
      e.preventDefault();
      this.handleSendMessage();
    }
    else if (e.key === 'Backspace') {
      if (this.textArea.value.endsWith('\n')) {
        this.textArea.style.height = this.textArea.clientHeight - 20 + 'px';
      }
      else if (this.textArea.value === '') {
        this.textArea.style.height = 'auto';
      }
    }
  }
  handleKeyUp(e) {
    if (e.key === 'Shift') {
      this.shiftDown = false;
    }
  }
  uploadFile(type) {
    const input = document.createElement('input');
    input.type = 'file';
    if (type === 'image') {
      input.accept = 'image/*';
    }
    input.onchange = (e) => {
      const { validity, files: [file], } = e.target;
      if (validity.valid) {
        this.sendFile(file, type);
      }
    };
    input.click();
  }
  handleFilesDataTransfer(items) {
    if (items == null)
      return;
    for (const item of items) {
      if (item.kind === 'file') {
        const file = item.getAsFile();
        if (item.type.startsWith('image/')) {
          this.sendFile(file, 'image');
        }
        else {
          this.sendFile(file, 'file');
        }
      }
    }
  }
  sendFile(file, type) {
    var _a, _b;
    if (!this.canSend || !this.canSendFiles) {
      return;
    }
    if (type === 'image') {
      (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.sendImageMessage(file);
    }
    else {
      (_b = this.meeting) === null || _b === void 0 ? void 0 : _b.chat.sendFileMessage(file);
    }
  }
  render() {
    let prevMessage = null;
    return (index$1.h(index$1.Host, null, index$1.h("div", { id: "dropzone", class: { active: this.dropzoneActivated } }, index$1.h("dyte-icon", { icon: this.iconPack.attach }), index$1.h("p", null, this.t('Drop files/images to send'))), index$1.h("div", { class: "chat-container scrollbar", ref: (el) => (this.chatEl = el) }, index$1.h("div", { class: "spacer" }), index$1.h("div", { class: "chat" }, this.chat.map((item) => {
      if (item.type === 'chat') {
        const { message } = item;
        const isContinued = message.userId === (prevMessage === null || prevMessage === void 0 ? void 0 : prevMessage.userId) &&
          differenceInMinutes(message.time, prevMessage === null || prevMessage === void 0 ? void 0 : prevMessage.time) < 2;
        prevMessage = message;
        switch (message.type) {
          case 'text':
            return (index$1.h("dyte-text-message", { message: message, now: this.now, isContinued: isContinued }));
          case 'image':
            return (index$1.h("dyte-image-message", { message: message, now: this.now, isContinued: isContinued, iconPack: this.iconPack }));
          case 'file':
            return (index$1.h("dyte-file-message", { message: message, now: this.now, isContinued: isContinued, iconPack: this.iconPack }));
        }
      }
    }))), index$1.h("form", { class: "chat-input" }, this.canSend && this.canSendTextMessage && (index$1.h("textarea", { placeholder: "Message..", ref: (el) => (this.textArea = el), onKeyDown: (e) => this.handleKeyDown(e), onKeyUp: (e) => this.handleKeyUp(e), autoFocus: true, onPaste: (e) => {
        const data = e.clipboardData || e.originalEvent.clipboardData;
        this.handleFilesDataTransfer(data.items);
      } })), index$1.h("div", { class: "chat-buttons" }, index$1.h("div", { class: "left" }, index$1.h("dyte-tooltip", { label: this.t(this.autoScrollEnabled ? 'Autoscroll enabled' : 'Autoscroll disabled') }, index$1.h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => (this.autoScrollEnabled = !this.autoScrollEnabled), class: { active: this.autoScrollEnabled }, title: this.t(this.autoScrollEnabled ? 'Autoscroll enabled' : 'Autoscroll disabled') }, index$1.h("dyte-icon", { icon: this.iconPack.vertical_scroll }))), this.canSend &&
      this.canSendFiles && [
      index$1.h("dyte-tooltip", { label: this.t('Send a file') }, index$1.h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => this.uploadFile('file'), title: this.t('Send a file') }, index$1.h("dyte-icon", { icon: this.iconPack.attach }))),
      index$1.h("dyte-tooltip", { label: this.t('Send an image') }, index$1.h("dyte-button", { variant: "ghost", kind: "icon", onClick: () => this.uploadFile('image'), title: this.t('Send an image') }, index$1.h("dyte-icon", { icon: this.iconPack.image }))),
    ], this.canSend && this.canSendTextMessage && (index$1.h("dyte-tooltip", { label: this.t('Send Emoji') }, index$1.h("dyte-button", { variant: "ghost", kind: "icon", title: this.t('Send Emoji') }, index$1.h("dyte-icon", { icon: this.iconPack.emoji_multiple }))))), this.canSend && this.canSendTextMessage && (index$1.h("div", { class: "right" }, index$1.h("dyte-tooltip", { variant: "brand", label: this.t('Send message') }, index$1.h("dyte-button", { kind: "icon", onClick: () => this.handleSendMessage(), title: this.t('Send message') }, index$1.h("dyte-icon", { icon: this.iconPack.send })))))))));
  }
  get host() { return index$1.getElement(this); }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteChat.style = dyteChatCss;

const dyteParticipantsCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{margin-top:var(--dyte-space-2, 8px);display:flex;height:100%;width:100%;flex-direction:column;font-size:14px}*{box-sizing:border-box}h3,.heading-count{margin:var(--dyte-space-0, 0px);display:flex;height:var(--dyte-space-12, 48px);align-items:center;justify-content:center;font-size:16px;font-weight:400;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));text-align:center}.ctr{box-sizing:border-box;padding-left:var(--dyte-space-3, 12px);padding-right:var(--dyte-space-3, 12px);padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px);padding-top:var(--dyte-space-0, 0px);overflow-y:auto;flex-grow:1;flex-basis:0}.search{position:-webkit-sticky;position:sticky;box-sizing:border-box;display:flex;align-items:center;border-radius:var(--dyte-border-radius-sm, 4px);--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity))}.search dyte-icon{margin-left:var(--dyte-space-2, 8px);margin-right:var(--dyte-space-2, 8px);height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px);color:rgb(var(--dyte-colors-text-600, 255 255 255 / 0.52))}.search input{box-sizing:border-box;height:var(--dyte-space-9, 36px);width:100%;padding-right:var(--dyte-space-2, 8px);border-width:var(--dyte-border-width-none, 0);border-style:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-700, 44 44 44) / var(--tw-bg-opacity));color:rgb(var(--dyte-colors-text-1000, 255 255 255));outline:2px solid transparent;outline-offset:2px;border-radius:var(--dyte-border-radius-sm, 4px);font-size:14px}.search input::-moz-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}.search input:-ms-input-placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}.search input::placeholder{color:rgb(var(--dyte-colors-text-800, 255 255 255 / 0.76))}.participants{margin-top:var(--dyte-space-4, 16px);padding:var(--dyte-space-0, 0px)}.heading-count{font-size:14px}.empty-message{margin-top:var(--dyte-space-10, 40px);margin-bottom:var(--dyte-space-10, 40px);text-align:center;font-size:14px;color:rgb(var(--dyte-colors-text-700, 255 255 255 / 0.64))}";

const DyteParticipants = class {
  constructor(hostRef) {
    index$1.registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$2.useLanguage();
    this.search = '';
    this.participants = [];
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    this.participantJoinedListener &&
      this.meeting.participants.joined.removeListener('participantJoined', this.participantJoinedListener);
    this.participantLeftListener &&
      this.meeting.participants.joined.removeListener('participantLeft', this.participantLeftListener);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.participants = [meeting.self, ...meeting.participants.joined.toArray()];
      this.participantJoinedListener = (peer) => {
        if (!this.participants.some((p) => p.id === peer.id)) {
          this.participants = [...this.participants, peer];
        }
      };
      this.participantLeftListener = (peer) => {
        this.participants = this.participants.filter((p) => p.id !== peer.id);
      };
      meeting.participants.joined.addListener('participantJoined', this.participantJoinedListener);
      meeting.participants.joined.addListener('participantLeft', this.participantLeftListener);
    }
  }
  getParticipants() {
    const search = this.search.trim();
    if (search === '') {
      return this.participants;
    }
    return this.participants.filter((p) => { var _a; return ((_a = p.name) !== null && _a !== void 0 ? _a : p.id).toLowerCase().includes(search.toLowerCase()); });
  }
  render() {
    const participants = this.getParticipants();
    return (index$1.h(index$1.Host, null, index$1.h("div", { class: "ctr scrollbar" }, index$1.h("div", { class: "heading-count" }, this.t('In Call'), " (", this.participants.length, ")"), index$1.h("div", { class: "search" }, index$1.h("dyte-icon", { icon: this.iconPack.search }), index$1.h("input", { type: "search", autocomplete: "off", placeholder: "Search", onInput: (e) => {
        this.search = e.target.value;
      } })), index$1.h("ul", { class: "participants" }, participants.map((peer) => (index$1.h("dyte-participant", { role: "listitem", key: peer.id, meeting: this.meeting, peer: peer }))), participants.length === 0 && (index$1.h("div", { class: "empty-message" }, "It looks like nobody's here"))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DyteParticipants.style = dyteParticipantsCss;

const dytePluginsCss = ".scrollbar{scrollbar-width:thin;scrollbar-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))\n    var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar{height:var(--dyte-space-1\\.5, 6px);width:var(--dyte-space-1\\.5, 6px);border-radius:9999px;background-color:var(--dyte-scrollbar-background, transparent)}.scrollbar::-webkit-scrollbar-thumb{border-radius:9999px;background-color:var(--dyte-scrollbar-color, rgb(var(--dyte-colors-background-600, 60 60 60)))}:host{margin-top:var(--dyte-space-2, 8px);margin-bottom:var(--dyte-space-2, 8px);display:flex;height:100%;width:100%;flex-direction:column;font-family:var(--dyte-font-family, sans-serif);font-size:14px}h3{margin-left:var(--dyte-space-0, 0px);margin-right:var(--dyte-space-0, 0px);margin-top:var(--dyte-space-4, 16px);margin-bottom:var(--dyte-space-4, 16px);display:block;padding:var(--dyte-space-0, 0px);font-size:16px;font-weight:400;color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));text-align:center}ul{overflow-y:auto;padding:var(--dyte-space-0, 0px);flex-grow:1;flex-basis:0}.metadata{display:flex;align-items:center}.metadata img{height:var(--dyte-space-8, 32px);width:var(--dyte-space-8, 32px);border-radius:var(--dyte-border-radius-sm, 4px)}.metadata .name{margin-left:var(--dyte-space-2, 8px);font-weight:500}.plugin{display:flex;align-items:center;justify-content:space-between;padding-left:var(--dyte-space-4, 16px);padding-right:var(--dyte-space-4, 16px);padding-top:var(--dyte-space-2, 8px);padding-bottom:var(--dyte-space-2, 8px)}.plugin .buttons{display:flex;align-items:center}dyte-button{height:var(--dyte-space-10, 40px);width:var(--dyte-space-10, 40px)}dyte-button:hover,dyte-button:focus{--tw-ring-offset-shadow:var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow:var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow, 0 0 #0000);--tw-ring-opacity:1;--tw-ring-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-ring-opacity));--tw-ring-offset-width:2px;--tw-ring-offset-color:rgb(var(--dyte-colors-background-1000, 8 8 8))}";

const DytePlugins = class {
  constructor(hostRef) {
    index$1.registerInstance(this, hostRef);
    /** Icon pack */
    this.iconPack = defaultIconPack.defaultIconPack;
    /** Language */
    this.t = index$2.useLanguage();
    this.plugins = [];
    this.canStartPlugins = false;
    this.canClosePlugin = false;
    this.activatedPluginsId = [];
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    this.meeting.plugins.all.removeListener('stateUpdate', this.updateActivePlugins);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.canStartPlugins = meeting.self.permissions.plugins.canStart;
      this.canClosePlugin = meeting.self.permissions.plugins.canClose;
      this.plugins = meeting.plugins.all.toArray();
      this.updateActivePlugins = () => {
        this.activatedPluginsId = meeting.plugins.active.toArray().map((p) => p.id);
      };
      this.updateActivePlugins();
      meeting.plugins.all.addListener('stateUpdate', this.updateActivePlugins);
    }
  }
  render() {
    return (index$1.h(index$1.Host, null, index$1.h("ul", { class: "scrollbar" }, this.plugins.map((plugin) => (index$1.h("li", { key: plugin.name, class: "plugin" }, index$1.h("div", { class: "metadata" }, index$1.h("img", { src: plugin.picture }), index$1.h("div", { class: "name" }, plugin.name)), !this.activatedPluginsId.includes(plugin.id) && this.canStartPlugins && (index$1.h("div", { class: "buttons" }, index$1.h("dyte-button", { kind: "icon", onClick: () => {
        plugin.activate();
      }, "aria-label": `${this.t('Activate')} ${plugin.name}` }, index$1.h("dyte-icon", { icon: this.iconPack.rocket, tabIndex: -1, "aria-hidden": true })))), this.activatedPluginsId.includes(plugin.id) && this.canClosePlugin && (index$1.h("div", { class: "buttons" }, index$1.h("dyte-button", { kind: "icon", onClick: () => {
        plugin.deactivate();
      }, "aria-label": `${this.t('Close')} ${plugin.name}` }, index$1.h("dyte-icon", { icon: this.iconPack.dismiss, tabIndex: -1, "aria-hidden": true }))))))))));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"]
  }; }
};
DytePlugins.style = dytePluginsCss;

exports.dyte_chat = DyteChat;
exports.dyte_participants = DyteParticipants;
exports.dyte_plugins = DytePlugins;
