import { defaultConfig } from '../../lib/default-ui-config';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { Render } from '../../lib/render';
import { formatName, shorten } from '../../utils/string';
import { Component, Host, h, Prop, State, Watch } from '@stencil/core';
export class DyteFullGrid {
  constructor() {
    /** Active Peers */
    this.peers = [];
    /** Screenshare Peers */
    this.screenSharePeers = [];
    /** Active plugins */
    this.plugins = [];
    /** Aspect ratio */
    this.aspectRatio = '16:9';
    /** Gap between peers */
    this.gap = 10;
    /** Config object */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  connectedCallback() {
    this.screenSharePeersChanged(this.screenSharePeers);
    this.pluginsChanged(this.plugins);
  }
  screenSharePeersChanged(screenSharePeers = []) {
    if (this.activeTab == null && screenSharePeers.length > 0) {
      this.activeTab = { type: 'screenshare', peer: screenSharePeers[0] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  pluginsChanged(plugins) {
    if (plugins.length > 0) {
      const lastIndex = plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: plugins[lastIndex] };
    }
    else {
      this.revalidateActiveTab();
    }
  }
  revalidateActiveTab() {
    if (this.activeTab != null) {
      if (this.activeTab.type === 'screenshare') {
        const { peer } = this.activeTab;
        if (!this.screenSharePeers.some((p) => p.id === peer.id)) {
          this.reassignActiveTab();
        }
      }
      else {
        const { plugin } = this.activeTab;
        if (!this.plugins.some((p) => p.id === plugin.id)) {
          this.reassignActiveTab();
        }
      }
    }
  }
  reassignActiveTab() {
    if (this.screenSharePeers.length > 0) {
      this.activeTab = { type: 'screenshare', peer: this.screenSharePeers[0] };
    }
    else if (this.plugins.length > 0) {
      const lastIndex = this.plugins.length - 1;
      this.activeTab = { type: 'plugin', plugin: this.plugins[lastIndex] };
    }
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    return (h(Host, null,
      h("main", null,
        h("div", { class: "active-tab" }, this.activeTab &&
          (this.activeTab.type === 'screenshare' ? (h(Render, { element: "dyte-screenshare-view", defaults: defaults, props: {
              key: this.activeTab.peer.id,
              peer: this.activeTab.peer,
            }, childProps: { peer: this.activeTab.peer, isScreenShare: true }, deepProps: true })) : (h(Render, { element: "dyte-plugin-main", defaults: defaults, props: { key: this.activeTab.plugin.id, plugin: this.activeTab.plugin } })))),
        h("div", { class: "switcher" },
          h("div", { class: "list scrollbar" },
            this.screenSharePeers.map((peer) => {
              const name = formatName(peer.name);
              return (h("dyte-button", { title: `${name}'s Screen Share`, key: peer.id, kind: "icon", class: {
                  active: this.activeTab.type === 'screenshare' && this.activeTab.peer.id === peer.id,
                }, onClick: () => (this.activeTab = { type: 'screenshare', peer }) },
                h("div", { class: "col-center" },
                  h("dyte-icon", { icon: this.iconPack.share_screen_person }),
                  h("span", { class: "name" }, peer.id === this.meeting.self.id ? 'You' : shorten(name, 6)))));
            }),
            this.plugins.map((plugin) => (h("dyte-button", { title: plugin.name, key: plugin.id, kind: "icon", class: {
                active: this.activeTab.type === 'plugin' && this.activeTab.plugin.id === plugin.id,
              }, onClick: () => (this.activeTab = { type: 'plugin', plugin }) },
              h("div", { class: "col-center" },
                h("img", { src: plugin.picture }),
                h("span", { class: "name" }, shorten(plugin.name, 6))))))))),
      h("aside", null,
        h("div", { class: "list scrollbar" }, this.peers.map((peer) => (h(Render, { element: "dyte-peer-view", defaults: defaults, props: { key: peer.id, peer, size: 'sm' }, childProps: { peer, size: 'sm' }, deepProps: true })))))));
  }
  static get is() { return "dyte-full-grid"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-full-grid.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-full-grid.css"]
  }; }
  static get properties() { return {
    "peers": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer[]",
        "resolved": "Peer[]",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Active Peers"
      },
      "defaultValue": "[]"
    },
    "screenSharePeers": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer[]",
        "resolved": "Peer[]",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Screenshare Peers"
      },
      "defaultValue": "[]"
    },
    "plugins": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "DytePlugin[]",
        "resolved": "Readonly<DytePlugin>[]",
        "references": {
          "DytePlugin": {
            "location": "import",
            "path": "@dyte-in/client-core"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Active plugins"
      },
      "defaultValue": "[]"
    },
    "aspectRatio": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Aspect ratio"
      },
      "attribute": "aspect-ratio",
      "reflect": false,
      "defaultValue": "'16:9'"
    },
    "gap": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Gap between peers"
      },
      "attribute": "gap",
      "reflect": true,
      "defaultValue": "10"
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States"
      }
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config object"
      },
      "defaultValue": "defaultConfig"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ live: string; people: string; chat: string; poll: string; participants: string; rocket: string; video_background_effect: string; call_end: string; grid: string; share: string; check_mark: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; speaker_off: string; avatar: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; arrow_expand: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; arrow_minimize: string; image_off: string; disconnected: string; poor_network: string; wand: string; rejoin: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "activeTab": {}
  }; }
  static get watchers() { return [{
      "propName": "screenSharePeers",
      "methodName": "screenSharePeersChanged"
    }, {
      "propName": "plugins",
      "methodName": "pluginsChanged"
    }]; }
}
