import { Component, Host, h, Prop } from '@stencil/core';
import { formatName, shorten } from '../../utils/string';
import { useLanguage } from '../../lib/lang';
export class DyteNameTag {
  constructor() {
    /** Maximum length of the name */
    this.maxLength = 20;
    /** Language */
    this.t = useLanguage();
  }
  render() {
    const name = formatName(this.peer.name);
    const isSelf = this.peer.id === this.meeting.self.id;
    return (h(Host, { class: { [this.size]: this.size !== undefined }, title: name },
      h("slot", { name: "start" }),
      isSelf ? `${shorten(name, 13)} (${this.t('you')})` : shorten(name, 16),
      h("slot", { name: "end" })));
  }
  static get is() { return "dyte-name-tag"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-name-tag.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-name-tag.css"]
  }; }
  static get properties() { return {
    "peer": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Peer",
        "resolved": "({ readonly id: string; readonly name: string; readonly clientSpecificId: any; readonly preview: Pick<LocalMediaHandler, \"audioTrack\" | \"videoTrack\" | \"audioEnabled\" | \"videoEnabled\">; readonly role: any; readonly audioTrack: MediaStreamTrack; readonly videoTrack: MediaStreamTrack; readonly screenShareTracks: { audio?: MediaStreamTrack; video?: MediaStreamTrack; }; readonly audioEnabled: boolean; readonly videoEnabled: boolean; readonly screenShareEnabled: boolean; readonly mediaPermissions: { audio?: MediaPermission; video?: MediaPermission; }; readonly permissions: DytePermissionsPreset; readonly suggestedTheme: DyteThemePreset; readonly roomJoined: boolean; readonly setName: (name: string) => void; readonly setupTracks: (options?: { video?: boolean; audio?: boolean; }) => Promise<void>; readonly enableAudio: () => Promise<void>; readonly enableVideo: () => Promise<void>; readonly enableScreenShare: () => Promise<void>; readonly disableAudio: () => Promise<void>; readonly disableVideo: () => Promise<void>; readonly disableScreenShare: () => Promise<void>; readonly enablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly disablePreview: (options?: { audio?: boolean; video?: boolean; }) => Promise<void>; readonly getCurrentDevices: () => { audio: MediaDeviceInfo; video: MediaDeviceInfo; speaker: MediaDeviceInfo; }; readonly getAudioDevices: () => MediaDeviceInfo[]; readonly getVideoDevices: () => MediaDeviceInfo[]; readonly getSpeakerDevices: () => MediaDeviceInfo[]; readonly getDeviceById: (deviceId: string, kind: \"audio\" | \"video\" | \"speaker\") => MediaDeviceInfo; readonly getAllDevices: () => MediaDeviceInfo[]; readonly setDevice: (device: MediaDeviceInfo, preview?: boolean) => Promise<void>; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => void) => DyteSelf; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteSelf; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => DyteSelf; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => number; readonly setMaxListeners: (n: number) => DyteSelf; readonly getMaxListeners: () => number; readonly rawListeners: (event: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; }) | ({ readonly id: string; readonly userId: string; readonly name: string; readonly picture: string; readonly isHost: boolean; readonly clientSpecificId?: string; readonly flags: { [key: string]: string | boolean; }; readonly device: DeviceConfig; readonly videoTrack: MediaStreamTrack; readonly audioTrack: MediaStreamTrack; readonly screenShareTracks: { audio: MediaStreamTrack; video: MediaStreamTrack; }; readonly videoEnabled: boolean; readonly audioEnabled: boolean; readonly screenShareEnabled: boolean; readonly setVideoEnabled: (videoEnabled: boolean, emitEvent?: boolean) => void; readonly setAudioEnabled: (audioEnabled: boolean, emitEvent?: boolean) => void; readonly setScreenShareEnabled: (screenShareEnabled: boolean, emitEvent?: boolean) => void; readonly emit: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", ...args: any[]) => boolean; readonly on: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => void) => DyteParticipant; readonly addListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly off: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly once: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly prependOnceListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeListener: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\", callback: (...args: any[]) => any) => DyteParticipant; readonly removeAllListeners: (event?: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => DyteParticipant; readonly listeners: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => Function[]; readonly listenerCount: (event: \"roomJoined\" | \"*\" | \"added\" | \"deleted\" | \"connected\" | \"disconnected\" | \"poorConnection\" | \"roomLeft\" | \"audioUpdate\" | \"videoUpdate\" | \"screenShareUpdate\" | \"previewUpdate\" | \"deviceUpdate\" | \"chatUpdate\" | \"pinMessage\" | \"unpinMessage\" | \"pollsUpdate\" | \"participantJoined\" | \"participantLeft\" | \"participantsUpdate\" | \"viewModeChanged\" | \"pageChanged\" | \"activeSpeaker\" | \"pluginAdded\" | \"pluginDeleted\" | \"stateUpdate\") => number; readonly setMaxListeners: (n: number) => DyteParticipant; readonly getMaxListeners: () => number; readonly rawListeners: (event: string | symbol) => Function[]; readonly eventNames: () => (string | symbol)[]; })",
        "references": {
          "Peer": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Peer object"
      }
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "maxLength": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Maximum length of the name"
      },
      "attribute": "max-length",
      "reflect": false,
      "defaultValue": "20"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
}
