import { Component, Host, h, Prop, Watch, State } from '@stencil/core';
import DyteAudio from '../../lib/audio';
import { useLanguage } from '../../lib/lang';
export class DytePeersAudio {
  constructor() {
    /** Language */
    this.t = useLanguage();
    this.playStatus = 'playing';
  }
  componentDidLoad() {
    this.meetingChanged(this.meeting);
  }
  disconnectedCallback() {
    if (this.meeting == null)
      return;
    this.audioUpdateListener &&
      this.meeting.participants.active.removeListener('audioUpdate', this.audioUpdateListener);
    this.screenShareUpdateListener &&
      this.meeting.participants.joined.removeListener('screenShareUpdate', this.screenShareUpdateListener);
    this.participantLeftListener &&
      this.meeting.participants.joined.removeListener('participantLeft', this.participantLeftListener);
    this.deviceUpdateListener &&
      this.meeting.self.removeListener('deviceUpdate', this.deviceUpdateListener);
  }
  async meetingChanged(meeting) {
    if (meeting != null) {
      this.audio = new DyteAudio();
      this.audio.onError(() => {
        this.playStatus = 'aborted';
      });
      this.audio.play();
      const currentDevices = meeting.self.getCurrentDevices();
      if (currentDevices.speaker != null) {
        await this.audio.setDevice(currentDevices.speaker.deviceId);
      }
      this.audioUpdateListener = ({ id, audioEnabled, audioTrack }) => {
        const audioId = `audio-${id}`;
        if (audioEnabled && audioTrack != null) {
          this.audio.addTrack(audioId, audioTrack);
        }
        else {
          this.audio.removeTrack(audioId);
        }
      };
      {
        const participants = meeting.participants.active.toArray();
        for (const participant of participants) {
          this.audioUpdateListener(participant);
        }
      }
      this.participantLeftListener = ({ id }) => {
        this.audio.removeTrack(`audio-${id}`);
        this.audio.removeTrack(`screenshare-${id}`);
      };
      this.screenShareUpdateListener = ({ id, screenShareEnabled, screenShareTracks }) => {
        const audioId = `screenshare-${id}`;
        if (screenShareEnabled && screenShareTracks.audio != null) {
          this.audio.addTrack(audioId, screenShareTracks.audio);
        }
        else {
          this.audio.removeTrack(audioId);
        }
      };
      this.deviceUpdateListener = ({ device, preview }) => {
        if (preview)
          return;
        if (device.kind === 'audiooutput') {
          this.audio.setDevice(device.deviceId);
        }
      };
      meeting.participants.active.addListener('audioUpdate', this.audioUpdateListener);
      meeting.participants.joined.addListener('screenShareUpdate', this.screenShareUpdateListener);
      meeting.participants.joined.addListener('participantLeft', this.participantLeftListener);
      meeting.self.addListener('deviceUpdate', this.deviceUpdateListener);
    }
  }
  render() {
    return (h(Host, null, this.playStatus === 'aborted' && (h("div", { class: "overlay" },
      h("div", { class: "modal" },
        h("h3", null, this.t('Allow Audio Playback')),
        h("p", null, this.t('In order to play audio properly on your device, click the button below')),
        h("dyte-button", { onClick: () => {
            this.audio.play();
            this.playStatus = 'playing';
          }, title: this.t('Play Audio') }, this.t('Play Audio')))))));
  }
  static get is() { return "dyte-peers-audio"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-peers-audio.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-peers-audio.css"]
  }; }
  static get properties() { return {
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    }
  }; }
  static get states() { return {
    "playStatus": {}
  }; }
  static get watchers() { return [{
      "propName": "meeting",
      "methodName": "meetingChanged"
    }]; }
}
