import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { C as ChatHead } from './ChatHead.js';
import { s as sanitizeLink } from './string.js';
import { d as defaultIconPack } from './default-icon-pack.js';
import { d as downloadFile } from './file.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$3 } from './dyte-button2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';
import { d as defineCustomElement$1 } from './dyte-spinner2.js';

const dyteImageMessageCss = ".image-spinner{cursor:wait}.image-errored{cursor:not-allowed}";

const DyteImageMessage = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.showModal = createEvent(this, "dyteViewImage", 7);
    /** Date object of now, to calculate distance between dates */
    this.now = new Date();
    /** Whether the message is continued by same user */
    this.isContinued = false;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.status = 'loading';
  }
  render() {
    return (h(Host, null, !this.isContinued && (h(ChatHead, { name: this.message.displayName, time: this.message.time, now: this.now })), h("div", { class: "body" }, h("div", { class: { image: true, loaded: this.status === 'loaded' } }, h("img", { src: sanitizeLink(this.message.link), onLoad: () => {
        this.status = 'loaded';
      }, onError: () => {
        this.status = 'errored';
      }, onClick: () => {
        if (this.status === 'loaded') {
          this.showModal.emit(this.message);
        }
      } }), this.status === 'loading' && (h("div", { class: "image-spinner", title: this.t('Loading image'), "aria-label": this.t('Loading image') }, h("dyte-spinner", null))), this.status === 'errored' && (h("div", { class: "image-errored", title: this.t('Image not found'), "aria-label": this.t('Image not found') }, h("dyte-icon", { icon: this.iconPack.image_off }))), this.status === 'loaded' && (h("div", { class: "actions" }, h("dyte-button", { class: "action", variant: "outline", kind: "icon", onClick: () => this.showModal.emit(this.message) }, h("dyte-icon", { icon: this.iconPack.arrow_expand })), h("dyte-button", { class: "action", variant: "outline", kind: "icon", onClick: () => downloadFile(this.message.link, { fallbackName: 'image' }) }, h("dyte-icon", { icon: this.iconPack.download }))))))));
  }
  static get style() { return dyteImageMessageCss; }
}, [0, "dyte-image-message", {
    "message": [16],
    "now": [16],
    "isContinued": [516, "is-continued"],
    "iconPack": [16],
    "t": [16],
    "status": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-image-message", "dyte-button", "dyte-icon", "dyte-spinner"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-image-message":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteImageMessage);
      }
      break;
    case "dyte-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "dyte-spinner":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { DyteImageMessage as D, defineCustomElement as d };
