import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { d as defineCustomElement$3 } from './dyte-controlbar-button2.js';
import { d as defineCustomElement$2 } from './dyte-icon2.js';

const dytePluginsToggleCss = ":host{display:block}";

const DytePluginsToggle$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.pluginsActive = false;
  }
  connectedCallback() {
    this.statesChanged(this.states);
  }
  statesChanged(states) {
    if (states != null) {
      this.pluginsActive = this.states.activeSidebar && this.states.sidebar === 'plugins';
    }
  }
  togglePlugins() {
    this.pluginsActive = !(this.states.activeSidebar && this.states.sidebar === 'plugins');
    this.stateUpdate.emit({
      activeSidebar: this.pluginsActive,
      sidebar: this.pluginsActive ? 'plugins' : 'none',
    });
  }
  render() {
    const text = this.t('plugins');
    return (h(Host, { title: text }, h("dyte-controlbar-button", { class: { active: this.pluginsActive }, size: this.size, onClick: () => this.togglePlugins(), icon: this.iconPack.rocket, label: text })));
  }
  static get watchers() { return {
    "states": ["statesChanged"]
  }; }
  static get style() { return dytePluginsToggleCss; }
}, [1, "dyte-plugins-toggle", {
    "meeting": [16],
    "states": [16],
    "size": [513],
    "iconPack": [16],
    "t": [16],
    "pluginsActive": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-plugins-toggle", "dyte-controlbar-button", "dyte-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-plugins-toggle":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DytePluginsToggle$1);
      }
      break;
    case "dyte-controlbar-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "dyte-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const DytePluginsToggle = DytePluginsToggle$1;
const defineCustomElement = defineCustomElement$1;

export { DytePluginsToggle, defineCustomElement };
