import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as computePosition, o as offset, f as flip, s as shift, a as arrow } from './floating-ui.dom.esm.js';

const dyteTooltipCss = ":host{display:inline-block;font-family:var(--dyte-font-family, sans-serif)}#trigger{display:inline-block}.tooltip,#arrow{position:absolute;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-background-600, 60 60 60) / var(--tw-bg-opacity))}.tooltip{position:absolute;z-index:20;display:none;width:-webkit-max-content;width:-moz-max-content;width:max-content;padding-left:var(--dyte-space-2, 8px);padding-right:var(--dyte-space-2, 8px);padding-top:var(--dyte-space-1, 4px);padding-bottom:var(--dyte-space-1, 4px);border-radius:var(--dyte-border-radius-sm, 4px);color:rgb(var(--dyte-colors-text-900, 255 255 255 / 0.88));--tw-shadow:0 1px 2px 0 rgb(0 0 0 / 0.05);--tw-shadow-colored:0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000), var(--tw-ring-shadow, 0 0 #0000), var(--tw-shadow);font-size:12px}#arrow{position:absolute;height:var(--dyte-space-2, 8px);width:var(--dyte-space-2, 8px);transform:rotate(45deg)}:host([variant='brand']) .tooltip,:host([variant='brand']) #arrow{--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity))}";

const DyteMenu = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Tooltip label */
    this.label = '';
    /** Tooltip variant */
    this.variant = 'default';
    /** Placement of menu */
    this.placement = 'top';
    this.showMenu = () => {
      this.tooltipEl.style.display = 'block';
      this.update();
    };
    this.hideMenu = () => {
      this.tooltipEl.style.display = 'none';
    };
  }
  componentDidLoad() {
    this.triggerEl.addEventListener('focusin', this.showMenu);
    this.triggerEl.addEventListener('mouseenter', this.showMenu);
    this.triggerEl.addEventListener('focusout', this.hideMenu);
    this.triggerEl.addEventListener('mouseleave', this.hideMenu);
  }
  update() {
    computePosition(this.triggerEl, this.tooltipEl, {
      placement: this.placement,
      middleware: [offset(8), flip(), shift({ padding: 5 }), arrow({ element: this.arrowEl })],
    }).then(({ x, y, placement, middlewareData }) => {
      Object.assign(this.tooltipEl.style, {
        left: `${x}px`,
        top: `${y}px`,
      });
      const { x: arrowX, y: arrowY } = middlewareData.arrow;
      const staticSide = {
        top: 'bottom',
        right: 'left',
        bottom: 'top',
        left: 'right',
      }[placement.split('-')[0]];
      Object.assign(this.arrowEl.style, {
        left: arrowX != null ? `${arrowX}px` : '',
        top: arrowY != null ? `${arrowY}px` : '',
        right: '',
        bottom: '',
        [staticSide]: '-4px',
      });
    });
  }
  render() {
    return (h(Host, null, h("span", { part: "trigger", id: "trigger", ref: (el) => (this.triggerEl = el) }, h("slot", null)), h("div", { part: "tooltip", class: "tooltip", id: "tooltip", role: "tooltip", ref: (el) => (this.tooltipEl = el) }, h("div", { id: "arrow", ref: (el) => (this.arrowEl = el) }), this.label)));
  }
  static get style() { return dyteTooltipCss; }
}, [1, "dyte-tooltip", {
    "label": [1],
    "variant": [513],
    "size": [513],
    "placement": [1]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-tooltip"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-tooltip":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteMenu);
      }
      break;
  } });
}

export { DyteMenu as D, defineCustomElement as d };
