import { r as registerInstance, c as createEvent, h, H as Host } from './index-da7bf46b.js';
import { d as defaultIconPack } from './default-icon-pack-3c344d0e.js';
import { u as useLanguage } from './index-a651ed73.js';

const dyteChatToggleCss = ":host{position:relative;display:block;font-family:var(--dyte-font-family, sans-serif)}.unread-count{position:absolute;right:var(--dyte-space-3, 12px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity));font-size:12px;display:flex;height:var(--dyte-space-5, 20px);width:var(--dyte-space-5, 20px);align-items:center;justify-content:center;border-radius:9999px}";

const DyteChatToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    this.lastMessageCount = 0;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.chatActive = false;
    this.unreadMessageCount = 0;
    this.toggleChat = () => {
      this.chatActive = !(this.states.activeSidebar && this.states.sidebar === 'chat');
      this.unreadMessageCount = 0;
      this.lastMessageCount = this.meeting.chat.messages.length;
      this.stateUpdate.emit({
        activeSidebar: this.chatActive,
        sidebar: this.chatActive ? 'chat' : 'none',
      });
    };
  }
  connectedCallback() {
    this.statesChanged(this.states);
    this.meetingChanged(this.meeting);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.chatUpdateListener = ({ message }) => {
        if (message != null) {
          const diff = meeting.chat.messages.length - this.lastMessageCount;
          if (!this.chatActive) {
            this.unreadMessageCount = diff;
          }
          else {
            this.lastMessageCount = meeting.chat.messages.length;
          }
        }
      };
      this.unreadMessageCount = meeting.chat.messages.length;
      meeting.chat.addListener('chatUpdate', this.chatUpdateListener);
    }
  }
  statesChanged(states) {
    if (states != null) {
      this.chatActive = this.states.activeSidebar && this.states.sidebar === 'chat';
    }
  }
  render() {
    return (h(Host, { title: this.t('chat') }, this.unreadMessageCount !== 0 && !this.chatActive && (h("div", { class: "unread-count" }, h("span", null, this.unreadMessageCount))), h("dyte-controlbar-button", { class: { active: this.chatActive }, size: this.size, onClick: this.toggleChat, icon: this.iconPack.chat, label: this.t('chat') })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "states": ["statesChanged"]
  }; }
};
DyteChatToggle.style = dyteChatToggleCss;

export { DyteChatToggle as dyte_chat_toggle };
