import RoomNodeClient from '../roomNode/RoomNodeClient';
import SelfController from './SelfController';
import ParticipantController from './ParticipantController';
import MetaController from './MetaController';
import PluginController from './PluginController';
import ChatController from './ChatController';
import PollController from './PollController';
export interface Modules {
    chat?: boolean;
    participant?: boolean;
    plugin?: boolean;
    poll?: boolean;
    self?: boolean;
    room?: boolean;
    permissions?: boolean;
    theme?: boolean;
}
export interface ControllerOptions {
    roomName: string;
    authToken: string;
    apiBase?: string;
    defaults?: {
        video?: boolean;
        audio?: boolean;
    };
    modules?: Modules;
}
export default class Controller {
    #private;
    readonly apiBase: string;
    readonly chatController: ChatController;
    readonly metaController: MetaController;
    readonly participantController: ParticipantController;
    readonly pluginController: PluginController;
    readonly pollController: PollController;
    readonly selfController: SelfController;
    constructor(apiBase: string, metaController: MetaController, selfController: SelfController, pluginController: PluginController, participantController: ParticipantController, chatController: ChatController, pollController: PollController, roomNodeClient: RoomNodeClient);
    static init(options: ControllerOptions): Promise<Controller>;
    private static createRoomNodeClient;
    /**
     * A `roomJoined` event is emitted when a participant joins the room.
     */
    joinRoom(): Promise<void>;
    /**
     * A `roomLeft` event is emitted when a participant leaves the room.
     */
    leaveRoom(): Promise<void>;
}
